# Example 10: Merging Multiple PNG-Pack Files (PPFs)
#
# If working with multiple files, it might be worthwhile to merge those files into a single file.
# This particular program demonstrates how to use the "mergeGrid()" function, which makes this
# process efficient.

from pngpack import *
import numpy as np

# Create two arrays, one for each example file
dataOne = np.array([[1, 2], [3, 4]])
dataTwo = np.array([[5, 6], [7, 8]])

# Two files that will initially contain one array each
fileOne = Pack()
fileTwo = Pack()

fileOne.packGrid("example grid", dataOne)
fileTwo.packGrid("another example", dataTwo)

fileOne.save("to-be-merged-1.ppf")
fileTwo.save("to-be-merged-2.ppf")

# Load the two files that were just created
packOne = Pack("to-be-merged-1.ppf")
packTwo = Pack("to-be-merged-2.ppf")

print("Before merge:", packOne.getKeys())

# Grab the grid called "another example" from 'packTwo' and save it within 'packOne' under the same
# name.
packOne.mergeGrid(packTwo, "another example")

print("After merge:", packOne.getKeys())

# Verify the merge was successfull
extractedOne = packOne.unpackGrid("example grid")
extractedTwo = packOne.unpackGrid("another example")

print(extractedOne)
print(extractedTwo)

print()

print("Before another merge:", packOne.getKeys())

# Grab the grid called "another example" from 'packTwo' and save it within 'packOne' under the name
# "third example".
packOne.mergeGrid(packTwo, "another example", rename="third example")

print("After another merge:", packOne.getKeys())

# Again, verify the merge was successful
extractedThree = packOne.unpackGrid("third example")

print(extractedThree)