# Example 2: Embedding Multiple Arrays Into One File
#
# This includes the same array of temperatures as example1.py, and a new 16 element array of
# hypothetical wind speeds has also been provided.

from pngpack import *
import numpy as np


# A one-dimensional array of data
temperature = np.array([294.76703893, 298.54229312, 297.68941060, 288.01851419, 294.03889221, 300.56024075, 301.25782887, 300.11737928, 295.91656354, 292.28935541, 293.94085487, 294.47850144, 293.79480002, 288.96294355, 299.31238691, 293.71648222])
windSpeed = np.array([1.93054096, 0.65546064, 0.70894567, 0.85969939, 2.12386767, 1.79836234, 0.86474430, 3.15243281, 2.11965851, 3.12210652, 3.28538769, 1.22940893, 2.29379493, 2.01792410, 2.09836517, 3.28030442])

# Create a new file
myFile = Pack()


# Save the arrays into the new file
myFile.packGrid("T", temperature, units="Kelvin")
myFile.packGrid("wind", windSpeed, units="Meters Per Second")

# Also including units here, this is just a string with nothing particularly special about what's in
# the quotes. Doing units="K" and units="m/s" would also work.


# Save the file
myFile.save("16 Observations")


# Load the file that was saved above
loadedFile = Pack("16 Observations.ppf")


# Extract the array that was just saved
temperatureData = loadedFile.unpackGrid("T")
windSpeedData = loadedFile.unpackGrid("wind")

print(loadedFile.getUnits("T"))
print(loadedFile.getUnits("wind"))


# Calculate the mean data loss for our reference
temperatureError = np.abs(temperatureData - temperature)
windError = np.abs(windSpeedData - windSpeed)

print("Temperature array...")
print("Maximum loss:", temperatureError.max())
print("Average loss:", temperatureError.mean())
print()
print("Wind speed array...")
print("Maximum loss:", windError.max())
print("Average loss:", windError.mean())


