# Example 4: Dealing With Multiple Orders of Magnitude
#
# Some metrics may span multiple orders of magnitude, and this compression technique will not handle
# any such metrics very well. However, you can take the logarithm of the data, save it, then use the
# appropriate exponent to recover the data later (although, keep in mind that logarithmic data will
# be subject to larger errors, as this example will demonstrate).

from pngpack import *
import numpy as np


# A one-dimensional array of hypothetical pressure data
pressure = np.array([[1000, 975, 950, 925, 900, 875, 850, 825, 800, 775, 750, 725, 700, 650, 600, 550, 500, 450, 400, 350, 300, 250, 200, 150, 100, 50, 30, 20, 10, 5, 3, 2, 1]])


# Create a new file
myFile = Pack()


# Take the logarithm (base 10) of the data before saving it.
logPressure = np.log10(pressure)


# Save the array into the new file
myFile.packGrid("pressure", logPressure, units="log10(mb)")


# Save the file
myFile.save("Under Pressure")


# Load the file that was saved above
loadedFile = Pack("Under Pressure.ppf")


# Extract the array that was just saved
logExtracted = loadedFile.unpackGrid("pressure")


# Raise the data to the power of 10 to invert the logarithm
extracted = 10**logExtracted


print(extracted)


# Calculate the mean data loss for our reference
error = np.abs(extracted - pressure)
print("Maximum loss:", error.max())
print("Average loss:", error.mean())

