# Example 5: Three Dimensional Datasets
#
# Since PNG files handle data that is two-dimensional, encoding a three-dimensional dataset will
# present a problem. Arguably the best solution is to tile the three-dimensional data into a large
# two-dimensional grid and save that instead. The original dataset can be easily recovered so long as
# you know the dimensions of the tiled set.

from pngpack import *
import numpy as np


# A hypothetical three-dimensional array that is 4 x 2 x 2
example = np.array([[[4,  8,  10],
                     [9,  5,  6 ],
                     [33, 29, 20]],
                    [[6,  6,  12],
                     [11, 18, 19],
                     [43, 40, 38]],
                    [[6,  6,  12],
                     [11, 16, 19],
                     [43, 40, 38]],
                    [[1,  2,  18],
                     [20, 25, 26],
                     [55, 51, 60]],
                    [[1,  2,  18],
                     [20, 29, 26],
                     [55, 51, 60]],
                    [[3,  7,  17],
                     [14, 15, 16],
                     [69, 68, 70]]])


# Both of these will produce the same result, leaving out the (x, y) tiling will make the function
# create a tile set that is as close to a square as possible.
tileOne, dimOne = tileGrid(example, (3, 2))
tileTwo, dimTwo = tileGrid(example)

print(tileOne)
print(tileTwo)

# To reconstruct the original three-dimensional dataset, simply call the appropriate function and
# include the dimensions that were returned back (stored in "dimOne" and "dimTwo" in this case)

originalOne = untileGrid(tileOne, dimOne)
originalTwo = untileGrid(tileTwo, dimTwo)

print(originalOne)
print(originalTwo)

# Now we have a grid that can be compressed and decompressed

myFile = Pack()
myFile.packGrid("exampleOne", tileOne, units=str(dimOne[0])+','+str(dimOne[1]))
myFile.packGrid("exampleTwo", tileTwo, units=str(dimTwo[0])+','+str(dimTwo[1]))

myFile.save("3D Glasses")

loadedFile = Pack("3D Glasses.ppf")

dimensionOne = loadedFile.getUnits("exampleOne")
dimensionTwo = loadedFile.getUnits("exampleTwo")

print(dimensionOne)
print(dimensionTwo)

recoveredOne = untileGrid(loadedFile.unpackGrid("exampleOne"), dimensionOne)
recoveredTwo = untileGrid(loadedFile.unpackGrid("exampleTwo"), dimensionTwo)

print(recoveredOne)
print(recoveredTwo)
