# Example 8: Working With An Unfamiliar File
#
# Included in this package is an archive containing the SST data mentioned in the parent article (see
# the Read Me file for the URL). Here we're going to assume that this dataset was compiled by someone
# else, so we need to figure out how to work with it.

from pngpack import *
import numpy as np

dataFile = Pack("SST.ppf")

# This will show us how to retrieve values from the file. Note that the ensuing values in
# unpackGrid() are obtained form this print().
print(dataFile.getKeys())

# Retrieve the longitude array
longitude = dataFile.unpackGrid("longitude")
print(longitude)

# Retrieve the latitude array
latitude = dataFile.unpackGrid("latitude")
print(latitude)

# Retrieve the time array
time = dataFile.unpackGrid("time")
print(time)

# The sea-surface temperatures are three-dimensional in nature since there are multiple time values.
# How many time values? That can be answered with...

numGrids = dataFile.getPrefixCount("SST")
print(numGrids)

# The above function essentially tells us how many grids in the data file begin with the sequence
# "SST". This tells us how to retrieve all of the individual grids.

# This will tell us how to structure the following array called 'SST'.
gridShape = dataFile.unpackGrid("SST0").shape
print(gridShape)

SST = np.zeros([numGrids, gridShape[0], gridShape[1]])

for i in range(0, numGrids):
    SST[i,:,:] = dataFile.unpackGrid("SST"+str(i))

# And now we have the data!