# Example 9: Miscellaneous Library Functions
#
# The PNG-Pack module also includes functions that can be accessed without having a grid or data
# file. These functions are simply part of the compression operations, but if you want to customize
# something that is not already part of PNG-Pack's operations, then here are the names of the
# functions and some example uses:

from pngpack import *
import numpy as np


# This will create a list of hexadecimal (Base 16) place values that is 3 place values in length.
exampleList = generateBaseList(16, 3)
print(exampleList)

# Below are examples of the encode() function, which translates values into RGB or RGBA lists.
RGB = encode(3.14, 100, 3, exampleList, 16, 3)
RGBA = encode(3.14, 100, 3, generateBaseList(16, 4), 16, 4)
print(RGB, RGBA)

# Note that to improve computational efficiency, the function requires a base list be passed to it.
# Otherwise, the same base list would be recalculated every time a loop moved to a new grid point.
#
# Below are examples of the decode() function, which inverts the process and brings back the original
# value. Note that the number of channels is deduced from the length of the color list, so it is not
# included in the parameters.

originalA = decode(RGB, 100, 3, exampleList, 16)
originalB = decode(RGBA, 100, 3, generateBaseList(16, 4), 16)
print(originalA, originalB)

# For a specified range, number of channels, and separation value; calculate the highest value that
# can be used for the encoding parameter 'factor'.

bestFactor = maxFactor((2.7818281828, 3.1415926535), 4, 16)
print(bestFactor)

# Note that all of these functions also have docstrings.